==> haskell-presburger-1.3.1-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-presburger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: presburger
version: 1.3.1
id: presburger-1.3.1-FJZRuzKUd1k7MsF4Sswvdi
key: presburger-1.3.1-FJZRuzKUd1k7MsF4Sswvdi
license: BSD3
maintainer: diatchki@galois.com
homepage: http://github.com/yav/presburger
synopsis: A decision procedure for quantifier-free linear arithmetic.
description:
    The decision procedure is based on the algorithm used in
    CVC4, which is itself based on the Omega test.
category: Algorithms
author: Iavor S. Diatchki
exposed: True
indefinite: False
exposed-modules:
    Data.Integer.SAT
abi: d4364e117dc8c9b0b30974df3b4a8238
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/presburger-1.3.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/presburger-1.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/presburger-1.3.1
hs-libraries: HSpresburger-1.3.1-FJZRuzKUd1k7MsF4Sswvdi
depends:
    base-4.10.1.0 containers-0.5.10.2 pretty-1.1.3.3
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             pretty-1.1.3.3=da5c0455980712cd8d78cc4bdcee49dd
haddock-interfaces: /usr/share/doc/haskell-presburger/html/presburger.haddock
haddock-html: /usr/share/doc/haskell-presburger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-presburger-1.3.1-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-presburger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: presburger
version: 1.3.1
id: presburger-1.3.1-KXC8t3kM0alEcAX1uULthX
key: presburger-1.3.1-KXC8t3kM0alEcAX1uULthX
license: BSD-3-Clause
maintainer: diatchki@galois.com
author: Iavor S. Diatchki
homepage: http://github.com/yav/presburger
synopsis: A decision procedure for quantifier-free linear arithmetic.
description:
    The decision procedure is based on the algorithm used in
    CVC4, which is itself based on the Omega test.
category: Algorithms
abi: 16ae1a2f5c25c8a7b0a95c61b567e61f
exposed: True
exposed-modules:
    Data.Integer.SAT
import-dirs: /usr/lib/ghc-8.4.2/site-local/presburger-1.3.1
library-dirs: /usr/lib/ghc-8.4.2/site-local/presburger-1.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/presburger-1.3.1
hs-libraries: HSpresburger-1.3.1-KXC8t3kM0alEcAX1uULthX
depends:
    base-4.11.1.0 containers-0.5.11.0 pretty-1.1.3.6
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             containers-0.5.11.0=f8334bacfaf0e925ca7b24fb26fb2e66
             pretty-1.1.3.6=003e48b94caa84f26c31da01b81a0320
haddock-interfaces: /usr/share/doc/haskell-presburger/html/presburger.haddock
haddock-html: /usr/share/doc/haskell-presburger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
